@@ -6,7 +6,7 @@ from rich.console import Console
 from rich.theme import Theme
 from rich.progress import Progress
 
-from crudhex.domain.services import dsl_parser, db_entity_generator, config_context
+from crudhex.domain.services import dsl_parser, db_adapter_generator, config_context
 
 
 _CONF_HELP = f'Project config file to know packages and code paths. defaults to {config_context.DEFAULT_CONFIG}'
@@ -45,10 +45,15 @@ def generate(
 
         generate_task = progress.add_task('Generate classes', total=100)
         for entity in entities:
-            entity_path = db_entity_generator.create_entity_class(entity)
-            progress.update(generate_task, advance=100/len(entities))
+            entity_path = db_adapter_generator.create_entity_class(entity)
             progress.console.print(f'Generated entity: {entity_path.resolve()}', style='cyan')
 
+            repo_path = db_adapter_generator.create_repository_class(entity)
+            progress.console.print(f'Generated repository: {repo_path.resolve()}', style='cyan')
+
+            progress.update(generate_task, advance=100/len(entities))
+            progress.console.print('\n')
+
         progress.update(generate_task, advance=100)
 
     out_console.print('\nAll entities generated', style='success')
